@@ -22,7 +22,7 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <fnmatch.h>
+#include <pds/pdsfnmatch.h>
 
 #include <pds/pdscstring.h>
 #include <pds/pdsstring.h>
@@ -64,13 +64,13 @@ PdsCellString *pds_cell_string_new(int N)
 }
 
 
-/** \fn PdsCellString *pds_cell_string_copy_new(const PdsCellString *Cin)
+/** \fn PdsCellString *pds_cell_string_new_copy(const PdsCellString *Cin)
  *  \brief Crea un arreglo de células de tipo PdsCellString copiando los datos de otra.
  *  \param[in] Cin La célula a ser copiada.
  *  \return Un puntero a una estructura de tipo PdsCellString o NULL en caso de error.
  *  \ingroup PdsCellStringGroup
  */
-PdsCellString *pds_cell_string_copy_new(const PdsCellString *Cin)
+PdsCellString *pds_cell_string_new_copy(const PdsCellString *Cin)
 {
 	PdsCellString *C=NULL;
     int i,j;
@@ -329,7 +329,7 @@ int pds_cell_string_add_cell_string(PdsCellString *C,const PdsCellString *Cin)
 	if(C==NULL)       return FALSE;
 	if(Cin==NULL)     return TRUE;
 
-    Ctmp=pds_cell_string_copy_new(C);
+    Ctmp=pds_cell_string_new_copy(C);
 
     for(i=0;i<Cin->Ncell;i++)
     {
@@ -459,14 +459,14 @@ int pds_cell_string_findci(const PdsCellString *C,const char *str)
 
 
 
-/** \fn PdsCellString *pds_cell_string_new_load_data(const char*filepath)
+/** \fn PdsCellString *pds_cell_string_new_load(const char*filepath)
  *  \brief Crea un arreglo de células de tipo PdsCellString con los datos de cada 
  *  linea del archivo.
  *  \param[in] filepath La dirección del archivo de donde se cargarán los datos.
  *  \return Un puntero a una estructura de tipo PdsCellString.
  *  \ingroup PdsCellStringGroup
  */
-PdsCellString *pds_cell_string_new_load_data(const char*filepath)
+PdsCellString *pds_cell_string_new_load(const char*filepath)
 {
 	PdsCellString *C=NULL;
     char *line;
@@ -540,7 +540,8 @@ int pds_cell_string_remove(PdsCellString *C,int id)
  *  especificado por pattern.
  *
  *  \param[in,out] C El arreglo de células a remover datos.
- *  \param[in] pattern El patrón de búsqueda.
+ *  \param[in] pattern El patrón de búsqueda.Ejemplo: pattern->data[i] <-- "*.[ch]"
+ *  donde se aceptarán "*.c" o "*.h". La función cumple patrones aceptados por fnmatch().
  *  \return TRUE si todo fue bien o FALSE si no.
  *  En caso de error el contenido de C no es modificado. Si pattern es NULL no 
  *  es considerado error y se retorn TRUE sin hacer nada.
@@ -554,7 +555,7 @@ int pds_cell_string_filter_orinc(PdsCellString *C,const PdsCellString *pattern)
     if(C==NULL)         return  FALSE;
     if(pattern==NULL)   return  TRUE;
 
-    C0=pds_cell_string_copy_new(C);
+    C0=pds_cell_string_new_copy(C);
     if(C0==NULL)    return FALSE;
     
 
@@ -563,14 +564,14 @@ int pds_cell_string_filter_orinc(PdsCellString *C,const PdsCellString *pattern)
         fulfill_any_pattern=FALSE;
         for(j=0;j<pattern->Ncell;j++)
         {
-            if(fnmatch(pattern->data[j], C0->data[i], FNM_NOESCAPE)==0)
+            if(pds_fnmatch(pattern->data[j], C0->data[i], FNM_NOESCAPE)==0)
             {
                 fulfill_any_pattern=TRUE;
                 break;
             }
         }
 
-        if(!fulfill_any_pattern)
+        if(fulfill_any_pattern==FALSE)
         {
             dat=pds_cell_string_remove(C0,i);
             if(dat==FALSE)  return FALSE;
