@@ -30,13 +30,20 @@
 #include <fcntl.h>           /* Definition of AT_* constants */
 #include <unistd.h>
 #include <dirent.h>
-#include <fnmatch.h>
+#include <pds/pdsfnmatch.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
 
 #include <time.h>
 
+#define __BUFFER_SIZE__ 4096
+#if defined(_WINDOWS_) || defined(_WIN32) || defined(WIN32)
+    #include <windows.h>
+    #include <tchar.h>
+#endif
+
+
 /** \fn PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char* pattern_include,const char* pattern_exclude)
  *  \brief Retorna los archivos dentro de un directorio (siguiendo algunos criterios).
  *
@@ -59,9 +66,10 @@
 PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char* pattern_include,const char* pattern_exclude)
 {
     char *dir_path=NULL;
-    unsigned char  search_type;
+    int  search_type;
     char *PatternInc=NULL;
     char *PatternExc=NULL;
+    struct stat s;
 
     DIR *dir=NULL;
     struct dirent *lsdir=NULL;
@@ -72,14 +80,14 @@ PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char*
     if (strlen(dirpath)==0) return NULL;
 
 
-    dir_path=realpath(dirpath,NULL);
+    dir_path=pds_get_realpath(dirpath);
     if (dir_path==NULL)      return NULL;    
 
     dir = opendir(dir_path);
     if (dir==NULL)
     {
         TEMPORAL_STRING=(char *)calloc(strlen(dir_path)+32,sizeof(char));
-        sprintf(TEMPORAL_STRING,"ERROR opening %s",dir_path);
+        sprintf(TEMPORAL_STRING,"ERROR opening directory %s",dir_path);
         perror(TEMPORAL_STRING);
         free(TEMPORAL_STRING);
         return NULL;
@@ -89,13 +97,13 @@ PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char*
     fullnames=pds_cell_string_new(1);
     if(fullnames==NULL) return NULL;
 
-    if(Type==TYPE_DIR)          search_type=DT_DIR;
+    if(Type==TYPE_DIR)          search_type=S_IFDIR;
     else if(Type==TYPE_DIRTOP)  
     {
-        search_type=DT_DIR;
+        search_type=S_IFDIR;
         pds_cell_string_add(fullnames,dir_path);
     }
-    else                        search_type=DT_REG;
+    else                        search_type=S_IFREG;
 
 
     if (pattern_include==NULL)
@@ -114,6 +122,7 @@ PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char*
         sprintf(PatternInc,"%s",pattern_include);
     }
 
+
     if (pattern_exclude==NULL)
     {
         PatternExc=(char*)calloc(2,sizeof(char));
@@ -130,21 +139,22 @@ PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char*
         sprintf(PatternExc,"%s",pattern_exclude);
     }
 
+
     while ( ( lsdir = readdir(dir) ) != NULL )
     {
-        if(lsdir->d_type==search_type)
+        TEMPORAL_STRING=(char *)calloc(strlen(dir_path)+4+strlen(lsdir->d_name),sizeof(char));
+        sprintf(TEMPORAL_STRING,"%s%c%s",dir_path,pds_filesep(),lsdir->d_name);
+        stat(TEMPORAL_STRING, &s);
+        //printf("<<%s>>::%x::%x::%x\n",TEMPORAL_STRING,s.st_mode,S_IFREG,S_IFDIR);
+
+        if((s.st_mode & S_IFMT)==search_type)
         if( (strcmp(lsdir->d_name,".")!=0)&&(strcmp(lsdir->d_name,"..")!=0) )
-        if(fnmatch(PatternInc, lsdir->d_name, FNM_NOESCAPE)==0)
-        if(fnmatch(PatternExc, lsdir->d_name, FNM_NOESCAPE)!=0)
+        if(pds_fnmatch(PatternInc, lsdir->d_name, FNM_NOESCAPE)==0)
+        if(pds_fnmatch(PatternExc, lsdir->d_name, FNM_NOESCAPE)!=0)
         {
-
-            TEMPORAL_STRING=(char *)calloc(strlen(dir_path)+4+strlen(lsdir->d_name),sizeof(char));
-            sprintf(TEMPORAL_STRING,"%s%c%s",dir_path,pds_filesep(),lsdir->d_name);
-
             pds_cell_string_add(fullnames,TEMPORAL_STRING);
-
-            free(TEMPORAL_STRING);
         }
+        free(TEMPORAL_STRING);
     }
 
     closedir(dir);
@@ -163,6 +173,24 @@ PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char*
     }
 }
 
+/** \fn char *pds_get_homedir(void)
+ *  \brief Retorna una nueva cadena de texto con la dirección del directorio de 
+ *  usuario. HOME en gnu-linux y {HOMEDRIVE,HOMEPATH} en Windows.
+ *  \return Retorna el directorio de usuario o NULL en caso de problemas en la
+ *  reserva de memoria.
+ *  \ingroup PdsFilesFuncGroup
+ */
+char *pds_get_homedir(void)
+{
+    char homedir[__BUFFER_SIZE__];
+    #if defined(_WINDOWS_) || defined(_WIN32) || defined(WIN32)
+    snprintf(homedir, __BUFFER_SIZE__, "%s%s", getenv("HOMEDRIVE"), getenv("HOMEPATH"));
+    #elif defined(__linux__)
+    snprintf(homedir, __BUFFER_SIZE__, "%s", getenv("HOME"));
+    #endif
+    return strdup(homedir);
+}
+
 /** \fn char pds_filesep(void)
  *  \brief Retorna um caracter con el separador de archivo para el sistema.
  *  \return Retorna um caracter con el separador de archivo para el sistema.
@@ -226,7 +254,7 @@ PdsCellString *pds_get_all_subdirs_new(const char *dirpath,const char* pattern_i
                         return NULL;}
 
 
-    dir_path=realpath(dirpath,NULL);
+    dir_path=pds_get_realpath(dirpath);
     if(dir_path==NULL)    return NULL;
 
     dat=pds_cell_string_add(Ca,dir_path);
@@ -245,7 +273,9 @@ PdsCellString *pds_get_all_subdirs_new(const char *dirpath,const char* pattern_i
     do{
 
         Cb=pds_get_subdirs_new(Ca,pattern_include,pattern_exclude);
-
+        //printf("directorios:\n");
+        //if(Ca!=NULL)  pds_cell_string_all_printf(Cb);
+        //printf("____________\n");
 
         dat=pds_cell_string_add_cell_string(C0,Cb);
         if(dat==FALSE)  {   free(dir_path);
@@ -378,6 +408,49 @@ PdsCellString *pds_get_all_files_new(const char *dirpath,   const char* pattern_
 }
 
 
+/** \fn char *pds_get_realpath(const char* filepath)
+ *  \brief Expande todos los enlaces simbolicos y resuleve referencia a /./,
+ *  /../ y caracteres extras '/'  en filepath, asi es producido un pathname 
+ *  canonizado y absoluto. El resultado es cargado en una cadena nueva, 
+ *  retornada por la funcion. El path resultante no tiene enlaces simbolicos, 
+ *  /./ o /../ componentes. No expande '~/'.
+ *
+ *  Si la ruta de fichero es: ./Makefile
+ *                            src/../Makefile
+ *                            src/../////Makefile
+ *                            Makefile 
+ *  La función retorna:       /path_of_file/Makefile
+ *  \param[in] file_path Ruta del fichero a analizar. Este fichero tiene que existir,
+ *  caso contrario la función retornará NULL.
+ *  \return Retorna una nueva cadena de texto con el path absoluto y canonizado, 
+ *  o NULL en caso de error de reserva de memoria.
+ *  \ingroup PdsFilesFuncGroup
+ */
+char *pds_get_realpath(const char* filepath)
+{
+    char *file_path=NULL;
+
+    #if defined(_WINDOWS_) || defined(_WIN32) || defined(WIN32)
+    int i;
+    TCHAR  buffer[__BUFFER_SIZE__]=TEXT(""); 
+    DWORD retval = GetFullPathName(filepath,__BUFFER_SIZE__,buffer,NULL);
+    file_path=(char*)calloc(strlen(buffer)+1,sizeof(char));
+    for(i=0;i<strlen(buffer);i++)
+    {
+        wchar_t wc = buffer[i];
+        char c = (char)wc;
+        file_path[i] = c;
+    }
+    #elif defined(__linux__)
+    file_path=realpath(filepath,NULL);
+    #else
+    file_path=realpath(filepath,NULL);
+    #endif
+
+    return file_path;
+
+}
+
 /** \fn char *pds_get_basename(const char * file_path)
  *  \brief Obtén el nombre base desde una ruta de fichero.
  *
@@ -589,14 +662,14 @@ char *pds_get_temporal_filepath(const char *filepath,const char *groupname)
 
     if(directory==NULL)
         if(groupname==NULL)
-            cad=pds_sprintf("%s_%ld%d.%s",filename,clock(),rand(),ext);
+            cad=pds_sprintf("%s_%ld_%d.%s",filename,clock(),rand(),ext);
         else
-            cad=pds_sprintf("%s_%s%ld%d.%s",filename,groupname,clock(),rand(),ext);
+            cad=pds_sprintf("%s_%s%ld_%d.%s",filename,groupname,clock(),rand(),ext);
     else
         if(groupname==NULL)
-            cad=pds_sprintf("%s%c%s_%ld%d.%s",directory,pds_filesep(),filename,clock(),rand(),ext);
+            cad=pds_sprintf("%s%c%s_%ld_%d.%s",directory,pds_filesep(),filename,clock(),rand(),ext);
         else
-            cad=pds_sprintf("%s%c%s_%s%ld%d.%s",directory,pds_filesep(),filename,groupname,clock(),rand(),ext);
+            cad=pds_sprintf("%s%c%s_%s%ld_%d.%s",directory,pds_filesep(),filename,groupname,clock(),rand(),ext);
 
     free(ext);
     free(filename);
@@ -605,6 +678,83 @@ char *pds_get_temporal_filepath(const char *filepath,const char *groupname)
 }
 
 
+
+/** \fn char* pds_get_absolute_dirname(void)
+ *  \brief Obtén el directorio base del programa que invoca esta función.
+ *
+ *  Si la ruta del programa es: /path_to_file/programfilename
+ *  La función retorna:       /path_to_file
+ *  \return Retorna una nueva cadena de texto con el nombre del directorio base, 
+ *  o NULL en caso de error de reserva de memoria.
+ *  \ingroup PdsFilesFuncGroup
+ */
+char* pds_get_absolute_dirname(void)
+{
+    char exepath[__BUFFER_SIZE__];
+
+    #if defined(_WINDOWS_) || defined(_WIN32) || defined(WIN32)
+        int i;
+        TCHAR buffer[__BUFFER_SIZE__];
+        GetModuleFileName(NULL,buffer, __BUFFER_SIZE__) ;
+        for(i = 0; buffer[i]; ++i) 
+        {
+          wchar_t wc = buffer[i];
+          char c = (char)wc;
+          exepath[i] = c;
+        }
+    #elif defined(__linux__) 
+        int ID=readlink("/proc/self/exe", exepath,__BUFFER_SIZE__-1);
+        ID++;
+    #else
+        printf("The function pds_get_absolute_dirname() is not suported in this operating system.")
+        exepath[0]='.'
+    #endif
+
+    char *CMD=(char *)calloc(strlen(exepath)+1,sizeof(char));
+    sprintf(CMD,"%s",pds_get_dirname(exepath));
+
+    return CMD;
+}
+
+
+/** \fn char* pds_get_absolute_programpath(void)
+ *  \brief Obtén la ruta del programa que invoca esta función.
+ *
+ *  Si la ruta del programa es: /path_to_file/programfilename
+ *  La función retorna:       /path_to_file/programfilename
+ *  \return Retorna una nueva cadena de texto con el nombre de la ruta base, 
+ *  o NULL en caso de error de reserva de memoria.
+ *  \ingroup PdsFilesFuncGroup
+ */
+char* pds_get_absolute_programpath(void)
+{
+    char exepath[__BUFFER_SIZE__];
+
+    #if defined(_WINDOWS_) || defined(_WIN32) || defined(WIN32)
+        int i;
+        TCHAR buffer[__BUFFER_SIZE__];
+        GetModuleFileName(NULL,buffer, __BUFFER_SIZE__) ;
+        for(i = 0; buffer[i]; ++i) 
+        {
+          wchar_t wc = buffer[i];
+          char c = (char)wc;
+          exepath[i] = c;
+        }
+    #elif defined(__linux__)
+        int ID=readlink("/proc/self/exe", exepath,__BUFFER_SIZE__-1);
+        ID++;
+    #else
+        printf("The function pds_get_absolute_dirname() is not suported in this operating system.")
+        exepath[0]='.'
+    #endif
+
+    char *CMD=(char *)calloc(strlen(exepath)+1,sizeof(char));
+    sprintf(CMD,"%s",exepath);
+
+    return CMD;
+}
+
+
 /** \fn PdsCellString *pds_get_all_filename_extensions(const char *dirpath,   const char* pattern_include,const char* pattern_exclude,const char* file_pattern_include,const char* file_pattern_exclude)
  *  \brief Retorna una estructura PdsCellString con un arreglo de células con las 
  *  extenciones de archivos en el directorio. No son buscados archivos en los directorios simbólicos.
@@ -776,7 +926,9 @@ char *pds_read_line(FILE *fd)
  *
  *  \param[in] pathname Fichero de texto a analizar.
  *  \param[in] pattern Patrón a buscar.
- *  \return Retorna una nueva cadena de texto con el dato encontrado.
+ *  \return Retorna una nueva cadena de texto con el dato encontrado,
+ *  una cadena vacia si no existe ningun dato o NULL
+ *  si se encontró algun error.
  *  \ingroup PdsFilesFuncGroup
  */
 char *pds_get_filedata_string(const char *pathname,const char* pattern)
@@ -809,21 +961,26 @@ char *pds_get_filedata_string(const char *pathname,const char* pattern)
             if(Nl>=N)
             if(strncmp(pattern,LINE,N)==0)
             {
-            
-
                 DATA=(char*)calloc(Nl-N+1,sizeof(char));
                 if(DATA==NULL)
                 {
                     fprintf(stderr,"ERROR while alloc memory.\n");
- 
+                    fclose(fd);
+                    free(LINE);
+                    return NULL;
                 }
-                else for(i=N;i<Nl;i++)   DATA[i-N]=LINE[i];
+                for(i=N;i<Nl;i++)   DATA[i-N]=LINE[i];
 
                 break;
             }
         }
     }
 
+    if(DATA==NULL)
+    {
+        DATA=(char*)calloc(1,sizeof(char));
+    }
+
     fclose(fd);
     free(LINE);
 
@@ -834,12 +991,15 @@ char *pds_get_filedata_string(const char *pathname,const char* pattern)
 /** \fn PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pattern,const char *separator)
  *  \brief La funcion analiza linea por linea el archivo y retorna
  *  el texto despues de el primer patrón pattern encontrado, Pero estos datos son
- *  separados usando separator y ordenandos en una PdsCellString.
+ *  separados usando algunos de los separadores usados en separator y ordenandos en una PdsCellString.
  *
  *  \param[in] pathname Fichero de texto a analizar.
  *  \param[in] pattern Patrón a buscar.
- *  \param[in] separator Separador de texto.
+ *  \param[in] separator Separador de texto. Si separator es igual a NULL o vacia la 
+ *  función retorna la cadena sem dividir.
  *  \return Retorna una nueva estructurs PdsCellString con los datos encontrado.
+ *  Si no se encontró nada retorna una estructura vacia o NULL
+ *  si se encontró algun error.
  *  \ingroup PdsFilesFuncGroup
  */
 PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pattern,const char *separator)
@@ -853,7 +1013,9 @@ PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pat
     DATA=pds_get_filedata_string(pathname,pattern);
     if(DATA==NULL)  return  NULL;
 
-    CELL=pds_strsep (DATA,separator);
+    if(separator!=NULL) CELL=pds_strsep_cell_string (DATA,separator);
+    else                CELL=pds_strsep_cell_string (DATA,"");
+
 
     free(DATA);
     return CELL;
@@ -871,8 +1033,10 @@ int pds_is_file(const char *path)
     struct stat stat_result;
     stat(path, &stat_result);
 
-    if(S_ISREG(stat_result.st_mode))    return TRUE;
-    else                                return FALSE;
+    if( access( path, F_OK ) == -1 ) return FALSE;
+
+    if(S_ISREG(stat_result.st_mode)==0) return FALSE;
+    else                                return TRUE;
 }
 
 
@@ -888,6 +1052,8 @@ int pds_is_dir(const char *path)
     struct stat stat_result;
     stat(path, &stat_result);
 
+    if( access( path, F_OK ) == -1 ) return FALSE;
+
     if(S_ISDIR(stat_result.st_mode))    return TRUE;
     else                                return FALSE;
 }
@@ -1140,3 +1306,8 @@ int pds_file_content_replacement(   const char *filename_out,const char *filenam
   
     return TRUE;
 }
+
+
+
+
+
