@@ -69,7 +69,11 @@ typedef struct
     int Ncell;
 }PdsCellString;
 
-
+/** @name pds_cell_string_<new_methods>
+ *  Funciones para crear celulas
+ *
+ * @{
+ */
 
 /** \fn PdsCellString *pds_cell_string_new(int N)
  *  \brief Crea un arreglo de células de tipo PdsCellString con N elementos 
@@ -81,27 +85,22 @@ typedef struct
 PdsCellString *pds_cell_string_new(int N);
 
 
-/** \fn PdsCellString *pds_cell_string_copy_new(const PdsCellString *Cin)
+/** \fn PdsCellString *pds_cell_string_new_copy(const PdsCellString *Cin)
  *  \brief Crea un arreglo de células de tipo PdsCellString copiando los datos de otra.
  *  \param[in] Cin La célula a ser copiada.
  *  \return Un puntero a una estructura de tipo PdsCellString o NULL en caso de error.
  *  \ingroup PdsCellStringGroup
  */
-PdsCellString *pds_cell_string_copy_new(const PdsCellString *Cin);
+PdsCellString *pds_cell_string_new_copy(const PdsCellString *Cin);
+
+//@}
 
 
-/** \fn int pds_cell_string_write(PdsCellString *C,int id,const char* string_data)
- *  \brief Escribe un dato de tipo char* en el elemento id del arreglo de células.
- *  \param[in,out] C El arreglo de células a escribir.
- *  \param[in] id Posición en donde escribir el dato.
- *  \param[in] string_data La cadena a escribir.
- *  \return TRUE si todo fue bien o FALSE si no. Retorna FALSE si el id está fuera 
- *  de rango.
- *  \ingroup PdsCellStringGroup
+/** @name pds_cell_string_<printf_methods>
+ *  Funciones para mostrar el contenido de celulas.
+ *
+ * @{
  */
-int pds_cell_string_write(PdsCellString *C,int id,const char* string_data);
-
-
 
 /** \fn int pds_cell_string_all_printf(const PdsCellString *C)
  *  \brief Imprime en pantalla los datos del arreglo de células de tipo puntero 
@@ -123,35 +122,14 @@ int pds_cell_string_all_printf(const PdsCellString *C);
  */
 int pds_cell_string_all_fprintf(FILE* fd,const PdsCellString *C);
 
+//@}
 
-/** \fn int pds_cell_string_save(FILE* fd,const PdsCellString *C)
- *  \brief Imprime en el descriptor de fichero los datos del arreglo de células 
- *  de tipo puntero PdsCellString. Escribe un dato por cada linea.
- *  \param[in] pathname La dirección de fichero sobre el cual escribir.
- *  \param[in] C El arreglo de células a escribir.
- *  \return TRUE si todo fue bien o FALSE si no.
- *  \ingroup PdsCellStringGroup
+
+/** @name pds_cell_string_<add_methods>
+ *  Funciones para agregar elementos a las celulas
+ *
+ * @{
  */
-int pds_cell_string_save(const char* pathname,const PdsCellString *C);
-
-
-/** \fn void pds_cell_string_free(PdsCellString *C)
- *  \brief Libera un arreglo de células de tipo puntero PdsCellString. 
- *  \param[in,out] C El arreglo de células a liberar.
- *  \return No retorna valor.
- *  \ingroup PdsCellStringGroup
- */
-void pds_cell_string_free(PdsCellString *C);
-
-
-/** \fn void pds_cell_string_destroy(PdsCellString **C)
- *  \brief Libera un arreglo de células de tipo puntero PdsCellString y carga con NULL.
- *  \param[in,out] C El arreglo de células a liberar.
- *  \return No retorna valor.
- *  \ingroup PdsCellStringGroup
- */
-void pds_cell_string_destroy(PdsCellString **C);
-
 
 /** \fn int pds_cell_string_add(PdsCellString *C,const char* string_data)
  *  \brief Agrega un elemento en la ultima posición vacía(NULL) del arreglo de células. 
@@ -180,6 +158,25 @@ int pds_cell_string_add(PdsCellString *C,const char* string_data);
  */
 int pds_cell_string_add_cell_string(PdsCellString *C,const PdsCellString *Cin);
 
+//@}
+
+/** @name pds_cell_string_<get_set_methods>
+ *  Funciones para establecer y leer datos.
+ *
+ * @{
+ */
+
+/** \fn int pds_cell_string_write(PdsCellString *C,int id,const char* string_data)
+ *  \brief Escribe un dato de tipo char* en el elemento id del arreglo de células.
+ *  \param[in,out] C El arreglo de células a escribir.
+ *  \param[in] id Posición en donde escribir el dato.
+ *  \param[in] string_data La cadena a escribir.
+ *  \return TRUE si todo fue bien o FALSE si no. Retorna FALSE si el id está fuera 
+ *  de rango.
+ *  \ingroup PdsCellStringGroup
+ */
+int pds_cell_string_write(PdsCellString *C,int id,const char* string_data);
+
 
 /** \fn int pds_cell_string_read(const PdsCellString* C,int id,char** string_data)
  *  \brief Lee una cadena de texto, en la posición id del arreglo de células.
@@ -193,6 +190,26 @@ int pds_cell_string_add_cell_string(PdsCellString *C,const PdsCellString *Cin);
 int pds_cell_string_read(const PdsCellString* C,int id,char** string_data);
 
 
+/** \fn int pds_cell_string_remove(PdsCellString *C,int id)
+ *  \brief Remueve la célula de posición id.
+ *
+ *  \param[in,out] C El arreglo de células a remover datos.
+ *  \param[in] id El id de la célula a remover.
+ *  \return TRUE si todo fue bien o FALSE si no.
+ *  En caso de error no modifica el contenido de C.
+ *  \ingroup PdsCellStringGroup
+ */
+int pds_cell_string_remove(PdsCellString *C,int id);
+
+//@}
+
+
+/** @name pds_cell_string_<methods>
+ *  Funciones varias con informacion de las células.
+ *
+ * @{
+ */
+
 /** \fn int pds_cell_string_get_ncell(const PdsCellString *C)
  *  \brief Cuenta la cantidad de células incluyendo las vacías.
  *  \param[in] C El arreglo de células a analizar.
@@ -213,6 +230,62 @@ int pds_cell_string_get_ncell(const PdsCellString *C);
  */
 int pds_cell_string_get_last_empty(const PdsCellString *C);
 
+//@}
+
+/** @name pds_cell_string_<save_load_methods>
+ *  Funciones salvar y cargar células.
+ *
+ * @{
+ */
+
+/** \fn int pds_cell_string_save(FILE* fd,const PdsCellString *C)
+ *  \brief Imprime en el descriptor de fichero los datos del arreglo de células 
+ *  de tipo puntero PdsCellString. Escribe un dato por cada linea.
+ *  \param[in] pathname La dirección de fichero sobre el cual escribir.
+ *  \param[in] C El arreglo de células a escribir.
+ *  \return TRUE si todo fue bien o FALSE si no.
+ *  \ingroup PdsCellStringGroup
+ */
+int pds_cell_string_save(const char* pathname,const PdsCellString *C);
+
+/** \fn PdsCellString *pds_cell_string_new_load(const char*filepath)
+ *  \brief Crea un arreglo de células de tipo PdsCellString con los datos de cada 
+ *  linea del archivo.
+ *  \param[in] filepath La dirección del archivo de donde se cargarán los datos.
+ *  \return Un puntero a una estructura de tipo PdsCellString.
+ *  \ingroup PdsCellStringGroup
+ */
+PdsCellString *pds_cell_string_new_load(const char*filepath);
+
+//@}
+
+/** @name pds_cell_string_filter_methods>
+ *  Funciones para filtrar celulas
+ *
+ * @{
+ */
+
+/** \fn int pds_cell_string_filter_orinc(PdsCellString *C,const PdsCellString *pattern)
+ *  \brief Remueve las células que no cumplen con por lo menos un patrón 
+ *  especificado por pattern.
+ *
+ *  \param[in,out] C El arreglo de células a remover datos.
+ *  \param[in] pattern El patrón de búsqueda.Ejemplo: pattern->data[i] <-- "*.[ch]"
+ *  donde se aceptarán "*.c" o "*.h". La función cumple patrones aceptados por fnmatch().
+ *  \return TRUE si todo fue bien o FALSE si no.
+ *  En caso de error el contenido de C no es modificado. Si pattern es NULL no 
+ *  es considerado error y se retorn TRUE sin hacer nada.
+ *  \ingroup PdsCellStringGroup
+ */
+int pds_cell_string_filter_orinc(PdsCellString *C,const PdsCellString *pattern);
+
+//@}
+
+/** @name pds_cell_string_<find_and_make_methods>
+ *  Funciones para buscar cadenas y realizar operaciones.
+ *
+ * @{
+ */
 
 /** \fn int pds_cell_string_find(const PdsCellString *C,const char *str)
  *  \brief Retorna el id de la primera ocurrencia de la cadena str en el arreglo de 
@@ -238,41 +311,6 @@ int pds_cell_string_find(const PdsCellString *C,const char *str);
 int pds_cell_string_findci(const PdsCellString *C,const char *str);
 
 
-/** \fn PdsCellString *pds_cell_string_new_load_data(const char*filepath)
- *  \brief Crea un arreglo de células de tipo PdsCellString con los datos de cada 
- *  linea del archivo.
- *  \param[in] filepath La dirección del archivo de donde se cargarán los datos.
- *  \return Un puntero a una estructura de tipo PdsCellString.
- *  \ingroup PdsCellStringGroup
- */
-PdsCellString *pds_cell_string_new_load_data(const char*filepath);
-
-
-/** \fn int pds_cell_string_remove(PdsCellString *C,int id)
- *  \brief Remueve la célula de posición id.
- *
- *  \param[in,out] C El arreglo de células a remover datos.
- *  \param[in] id El id de la célula a remover.
- *  \return TRUE si todo fue bien o FALSE si no.
- *  En caso de error no modifica el contenido de C.
- *  \ingroup PdsCellStringGroup
- */
-int pds_cell_string_remove(PdsCellString *C,int id);
-
-
-/** \fn int pds_cell_string_filter_orinc(PdsCellString *C,const PdsCellString *pattern)
- *  \brief Remueve las células que no cumplen con por lo menos un patrón 
- *  especificado por pattern.
- *
- *  \param[in,out] C El arreglo de células a remover datos.
- *  \param[in] pattern El patrón de búsqueda.
- *  \return TRUE si todo fue bien o FALSE si no.
- *  En caso de error el contenido de C no es modificado. Si pattern es NULL no 
- *  es considerado error y se retorn TRUE sin hacer nada.
- *  \ingroup PdsCellStringGroup
- */
-int pds_cell_string_filter_orinc(PdsCellString *C,const PdsCellString *pattern);
-
 
 /** \fn int pds_cell_string_findci_and_add(PdsCellString *C,const char* string_data)
  *  \brief Agrega un nuevo registro de memoria si la cadena string_data no existe 
@@ -309,6 +347,32 @@ int pds_cell_string_find_and_remove(PdsCellString *C,const char *str);
  */
 int pds_cell_string_findci_and_remove(PdsCellString *C,const char *str);
 
+//@}
+
+/** @name pds_cell_string_<free_methods>
+ *  Funciones para liberar memoria
+ *
+ * @{
+ */
+
+/** \fn void pds_cell_string_free(PdsCellString *C)
+ *  \brief Libera un arreglo de células de tipo puntero PdsCellString. 
+ *  \param[in,out] C El arreglo de células a liberar.
+ *  \return No retorna valor.
+ *  \ingroup PdsCellStringGroup
+ */
+void pds_cell_string_free(PdsCellString *C);
+
+
+/** \fn void pds_cell_string_destroy(PdsCellString **C)
+ *  \brief Libera un arreglo de células de tipo puntero PdsCellString y carga con NULL.
+ *  \param[in,out] C El arreglo de células a liberar.
+ *  \return No retorna valor.
+ *  \ingroup PdsCellStringGroup
+ */
+void pds_cell_string_destroy(PdsCellString **C);
+
+//@}
 
 
 /**
