@@ -131,7 +131,9 @@ PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char*
  *
  *  \param[in] pathname Fichero de texto a analizar.
  *  \param[in] pattern Patrón a buscar.
- *  \return Retorna una nueva cadena de texto con el dato encontrado.
+ *  \return Retorna una nueva cadena de texto con el dato encontrado,
+ *  una cadena vacia si no existe ningun dato o NULL
+ *  si se encontró algun error.
  *  \ingroup PdsFilesFuncGroup
  */
 char *pds_get_filedata_string(const char *pathname,const char* pattern);
@@ -140,12 +142,15 @@ char *pds_get_filedata_string(const char *pathname,const char* pattern);
 /** \fn PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pattern,const char *separator)
  *  \brief La funcion analiza linea por linea el archivo y retorna
  *  el texto despues de el primer patrón pattern encontrado, Pero estos datos son
- *  separados usando separator y ordenandos en una PdsCellString.
+ *  separados usando algunos de los separadores usados en separator y ordenandos en una PdsCellString.
  *
  *  \param[in] pathname Fichero de texto a analizar.
  *  \param[in] pattern Patrón a buscar.
- *  \param[in] separator Separador de texto.
+ *  \param[in] separator Separador de texto. Si separator es igual a NULL o vacia la 
+ *  función retorna la cadena sem dividir.
  *  \return Retorna una nueva estructurs PdsCellString con los datos encontrado.
+ *  Si no se encontró nada retorna una estructura vacia o NULL
+ *  si se encontró algun error.
  *  \ingroup PdsFilesFuncGroup
  */
 PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pattern,const char *separator);
@@ -222,6 +227,35 @@ PdsCellString *pds_get_all_filename_extensions(const char *dirpath,   const char
  */
 
 
+/** \fn char *pds_get_realpath(const char* filepath)
+ *  \brief Expande todos los enlaces simbolicos y resuleve referencia a /./,
+ *  /../ y caracteres extras '/'  en filepath, asi es producido un pathname 
+ *  canonizado y absoluto. El resultado es cargado en una cadena nueva, 
+ *  retornada por la funcion. El path resultante no tiene enlaces simbolicos, 
+ *  /./ o /../ componentes. No expande '~/'.
+ *
+ *  Si la ruta de fichero es: ./Makefile
+ *                            src/../Makefile
+ *                            src/../////Makefile
+ *                            Makefile 
+ *  La función retorna:       /path_of_file/Makefile
+ *  \param[in] file_path Ruta del fichero a analizar. Este fichero tiene que existir,
+ *  caso contrario la función retornará NULL.
+ *  \return Retorna una nueva cadena de texto con el path absoluto y canonizado, 
+ *  o NULL en caso de error de reserva de memoria.
+ *  \ingroup PdsFilesFuncGroup
+ */
+char *pds_get_realpath(const char* filepath);
+
+/** \fn char *pds_get_homedir(void)
+ *  \brief Retorna una nueva cadena de texto con la dirección del directorio de 
+ *  usuario. HOME en gnu-linux y {HOMEDRIVE,HOMEPATH} en Windows.
+ *  \return Retorna el directorio de usuario o NULL en caso de problemas en la
+ *  reserva de memoria.
+ *  \ingroup PdsFilesFuncGroup
+ */
+char *pds_get_homedir(void);
+
 /** \fn char pds_filesep(void)
  *  \brief Retorna um caracter con el separador de archivo para el sistema.
  *  \return Retorna um caracter con el separador de archivo para el sistema.
@@ -318,6 +352,28 @@ char *pds_get_filepath_with_extension(const char *file_path,const char *extensio
 char *pds_get_temporal_filepath(const char *filepath,const char *groupname);
 
 
+/** \fn char* pds_get_absolute_dirname(void)
+ *  \brief Obtén el directorio base del programa que invoca esta función.
+ *
+ *  Si la ruta del programa es: /path_to_file/programfilename
+ *  La función retorna:       /path_to_file
+ *  \return Retorna una nueva cadena de texto con el nombre del directorio base, 
+ *  o NULL en caso de error de reserva de memoria.
+ *  \ingroup PdsFilesFuncGroup
+ */
+char* pds_get_absolute_dirname(void);
+
+/** \fn char* pds_get_absolute_programpath(void)
+ *  \brief Obtén la ruta del programa que invoca esta función.
+ *
+ *  Si la ruta del programa es: /path_to_file/programfilename
+ *  La función retorna:       /path_to_file/programfilename
+ *  \return Retorna una nueva cadena de texto con el nombre de la ruta base, 
+ *  o NULL en caso de error de reserva de memoria.
+ *  \ingroup PdsFilesFuncGroup
+ */
+char* pds_get_absolute_programpath(void);
+
 //@}
 
 
