@@ -66,17 +66,18 @@ extern "C" {
 char* pds_sprintf(const char *format, ...);
 
 
-/** \fn PdsCellString *pds_strsep(const char *str, const char *delim)
+/** \fn PdsCellString *pds_strsep_cell_string(const char *str, const char *delim)
  *  \brief Esta función es similar a la función strsep, donde la cadena str es 
  *  dividida usando algunos de los delimitadores especificados en delim. Los 
  *  pedazos son cargados en una estructura PdsCellString* retornada por la función.
  *  \param[in] str Cadena a dividir, esta cadena no sera modificada.
- *  \param[in] delim Delimitadores a usar.
+ *  \param[in] delim Delimitadores a usar. Si delim es NULL la función retorna NULL.
+ *  Si delim es una cadena vacia es retornada la cadena entera dentro de una PdsCellString.
  *  \return Retorna un puntero a una nueva estructura de tipo PdsCellString *,
  *  con los tokens de la división.
  *  \ingroup PdsStringGroup
  */
-PdsCellString *pds_strsep(const char *str, const char *delim);
+PdsCellString *pds_strsep_cell_string(const char *str, const char *delim);
 
 
 /** \fn int pds_strcicmp(const char *str0,const char *str1)
